@@ -1,7 +1,7 @@
 use strict;
 use warnings;
 package App::Cronjob;
-our $VERSION = '1.002';
+our $VERSION = '1.003';
 
 # ABSTRACT: wrap up programs to be run as cron jobs
 
@@ -200,7 +200,7 @@ sub send_cronjob_report {
 BEGIN {
 # Sure, a here-doc would be nicer, but PPI hates here-docs, I use PodPurler,
 # and PodPurler uses PPI.  Oh well. -- rjbs, 2009-04-21
-$TEMPLATE = q<
+$TEMPLATE = q!
 Command: { $command }
 Time   : { $time }s
 Status : { String::Flogger->flog([ '%s', \%waitpid ]) }
@@ -208,7 +208,7 @@ Status : { String::Flogger->flog([ '%s', \%waitpid ]) }
 Output :
 
 { $output || '(no output)' }
->
+!
 }
 
 {
@@ -231,7 +231,7 @@ App::Cronjob - wrap up programs to be run as cron jobs
 
 =head1 VERSION
 
-version 1.002
+version 1.003
 
 =head1 AUTHOR
 
